"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,0)
        assert fx == 'pysourceinfo.PySourceInfo.getCallerNameOID'
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = 'tests.30_libs.040_PySourceInfo.PySourceInfo_check_tests.check_callback'
        fx1 = 'PySourceInfo_check_tests.check_callback'
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,1)
        assert fx == fx0 or fx == fx1
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = 'tests.30_libs.040_PySourceInfo.getCallerNameOID.CallCase.CallUnits.testCase002'
        fx1 = '30_libs.040_PySourceInfo.getCallerNameOID.CallCase.CallUnits.testCase002'
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,2)

        assert fx == fx0 or fx == fx1

        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,3)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert fx == 'unittest.CallUnits.run'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case.CallUnits.run'
        else:
            assert False
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        
if __name__ == '__main__':
    unittest.main()



"""PyUnit tests

These tests could either be called from the command line,
or within Eclipse by the plugin PyDev / PyUnit.

* CLI: '*python setup.py test*' 

* Eclipse: Install PyDev, open the view PyUnit and proceed.


**REMARK**: For additional unit tests refer to subdirectory 'UseCases' 


30_libs
-------
Provided library modules of 'epyunit'.

"""
__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.2'
__uuid__='efed42d3-f801-4fbb-abfd-bd598d683a82'

__package__ = 'pysourceinfo_pyunit'



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

from pysourceinfo.PySourceInfo import getStackFuncNameMap,getStackLen,getCallerFunc


#
#######################
#
class CallUnits(unittest.TestCase):

    def callFunc(self,cfunc,param):
        """Function dummy, traces current stack by two different calls, normalizes the calls. 
        """
        return cfunc(param)

    def wrapStackDepth(self,deepness,cfunc,param):
        """Simulates depth of callstack.
        """
        if deepness > 0:
            _r = self.wrapStackDepth(deepness-1, cfunc, param)
        else:
            return self.callFunc(cfunc,param)
        return _r

    def testCase000(self):
        """simple upper call stack
        """
        c = self.wrapStackDepth(4, getStackFuncNameMap,'testCase000')
        assert c[7] == 'testCase000'
        pass

    def testCase001(self):
        """simple upper call stack
        """
        c = self.wrapStackDepth(4, getStackFuncNameMap,'wrapStackDepth')
        self.assertEqual( c, {
                2: 'wrapStackDepth',
                3: 'wrapStackDepth',
                4: 'wrapStackDepth',
                5: 'wrapStackDepth',
                6: 'wrapStackDepth',
            }
        )
        pass

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase003(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerFilePathName,3)
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'unittest.py'
        elif version == '2.7': # pragma: no cover
            assert os.path.basename(fx) == 'case.py'
        else:
            assert False
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = pysourceinfo.PySourceInfo.getModulePathName(pysourceinfo.PySourceInfo)
        
        fm = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModule,0)
        fx = pysourceinfo.PySourceInfo.getModulePathName(fm)

        assert os.path.normpath(fx) == fpn

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fpn = pysourceinfo.PySourceInfo.getModulePathName(PySourceInfo_check_tests)
        
        fm = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModule,1)
        fx = pysourceinfo.PySourceInfo.getModulePathName(fm)

        assert os.path.normpath(fx) == fpn

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fpn = os.path.abspath(os.path.normpath(os.path.dirname(__file__)))
        
        fm = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModule,2)
        fx = pysourceinfo.PySourceInfo.getModulePathName(fm)

        assert os.path.normpath(fx) == fpn

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fm = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModule,3)
        fx = pysourceinfo.PySourceInfo.getModulePathName(fm)
        fx = os.path.basename(fx)
        
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'python2.6'
        elif version == '2.7': # pragma: no cover
            assert os.path.basename(fx) == 'unittest'
        else:
            assert False

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerFuncName,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == 'testCase002'

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = pysourceinfo.PySourceInfo.getModulePathName(pysourceinfo.PySourceInfo)
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPathName,0)
        assert os.path.normpath(fx) == fpn

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = pysourceinfo.PySourceInfo.getModulePathName(PySourceInfo_check_tests)
        fx1 = pysourceinfo.PySourceInfo.getModulePathName(pysourceinfo)
#         fx0 = PySourceInfo_check_tests.__name__
#         fx1 = "tests"
#         
#         fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageName,1)
#         
#         # due to PyUnit path resolution dependent on curdir
#         assert fx == fx0 or fx == fx1

        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPathName,1)
        fx = os.path.normpath(fx)
        assert fx == fx0 or fx == fx1 

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fpn = os.path.abspath(os.path.normpath(os.path.dirname(__file__)))
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPathName,2)
        fx = os.path.normpath(fx)
        assert fx == fpn

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPathName,3)
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'python2.6'
        elif version == '2.7': # pragma: no cover
            assert os.path.basename(fx) == 'unittest'
        else:
            assert False

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

from pysourceinfo.PySourceInfo import getStackSposForFuncName,getStackFuncNameList


#
#######################
#
class CallUnits(unittest.TestCase):

    def callFunc(self,cfunc,param):
        return cfunc(param)

    def wrapStackDepth(self,deepness,cfunc,param):
        if deepness > 0:
            _r = self.wrapStackDepth(deepness-1, cfunc, param)
        else:
            return self.callFunc(cfunc,param)
        return _r

    def testCase000(self):

        c = self.wrapStackDepth(4, getStackFuncNameList,False)
        cRef =  [
            'getStackFuncNameList', 
            'callFunc', 
            'wrapStackDepth', 
            'wrapStackDepth', 
            'wrapStackDepth', 
            'wrapStackDepth', 
            'wrapStackDepth', 
            'testCase000',
        ]

        assert c[7] == cRef[7]

        ci = self.wrapStackDepth(4, getStackSposForFuncName,c[7])
        assert ci == 7
        pass

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _sx = repr(sys.path)

        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        fpn = pysourceinfo.PySourceInfo.getModuleSourceFilePathName(pysourceinfo)
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,0)

        # for relative calls
        fpn =os.path.abspath(fpn)
        fx =os.path.abspath(fx)

        assert os.path.normpath(fx) == fpn
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

    def testCase001(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        fx0 = os.path.dirname(__file__)+os.sep+'..'+os.sep+'PySourceInfo_check.py'
        fx1 = os.path.dirname(__file__)+os.sep+'..'+os.sep+'..'+os.sep+'__init__.py'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,1)

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx = os.path.normpath(fx)
        
        assert fx == fx0 or fx == fx1
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

    def testCase002(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx0  = os.path.normpath(os.path.dirname(__file__)+os.sep+'..'+os.sep+'..'+os.sep+'__init__.py')
        fx1  = os.path.normpath(os.path.dirname(__file__)+os.sep+'..'+os.sep+'__init__.py')
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,2)
        
        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx = os.path.normpath(fx)

        assert fx == fx0 or fx == fx1
         
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo
import testdata


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = os.path.abspath(os.path.normpath(os.path.dirname(pysourceinfo.__file__)))
#        fpn = os.path.abspath(os.path.normpath(os.path.dirname(pysourceinfo.__file__)+os.sep+".."))
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,0)
        fx = os.path.normpath(fx)
        self.assertEqual(fx, fpn)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]

        fx00 = os.path.realpath(os.path.abspath(os.path.dirname(testdata.__file__)+os.sep+'..'))
        sys.path.insert(0,fx00)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))

        import PySourceInfo_check_tests #@UnresolvedImport
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,2)
        fx = os.path.realpath(os.path.normpath(fx))
        fxchk = fx[len(fx00):len(fx00+os.path.sep+'tests')]
        self.assertEqual(fxchk, os.path.sep+'tests')         

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+".."+os.sep+".."+os.sep+".."
        #fx1 = os.path.dirname(PySourceInfo_check_tests.__file__)
        fx1 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+".."
        fx2 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+".."+os.sep+".."
        fx3 = os.path.dirname(__file__)
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,2)
        fx = os.path.normpath(fx)
        
        fx0 = os.path.abspath(fx0)
        fx1 = os.path.abspath(fx1)
        fx2 = os.path.abspath(fx2)
        fx3 = os.path.abspath(fx3)
        fx = os.path.abspath(fx)
        fx0 = os.path.realpath(os.path.normpath(fx0))
        fx1 = os.path.normpath(os.path.normpath(fx1))
        fx2 = os.path.normpath(os.path.normpath(fx2))
        fx3 = os.path.normpath(os.path.normpath(fx3))
        fx = os.path.normpath(os.path.normpath(fx))

        assert fx == fx0 or fx == fx1 or fx == fx2 or fx == fx3

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,3)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
#FIXME:            self.assertEqual(os.path.basename(fx[:-1]), "unittest.py")
            self.assertEqual(os.path.basename(fx), "unittest.py")
        elif version == '2.7': # pragma: no cover
            assert os.path.basename(fx) == "unittest"
        else:
            assert False

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = pysourceinfo.__name__
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageName,0)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fpn

    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fx0 = PySourceInfo_check_tests.__name__
        fx1 = "tests"
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageName,1)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        # due to PyUnit path resolution dependent on curdir
        assert fx == fx0 or fx == fx1

    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = '30_libs'
        fx1 = 'tests'
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageName,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1

    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageName,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == "unittest"

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase002(self):
        import sys
        _s=sys.path[:]
        
        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1

        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        
        fx0 = 'UseCases.PySourceInfo.getCallerModuleName.CallCase'
        fx1 = 'PySourceInfo.getCallerModuleName.CallCase'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1

    def testCase003(self):
        import sys
        _s=sys.path[:]

        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1

        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert fx == 'unittest'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case'
        else:
            assert False



if __name__ == '__main__':
    unittest.main()



"""Check pysourceinfo.PySourceInfo.getCallerPackagePythonPath
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase002(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        fx0 = os.path.normpath(os.path.dirname(__file__))
        fx1 = os.path.dirname(PySourceInfo_check.__file__)
        fx2 = os.path.dirname(PySourceInfo_check.__file__)+os.sep+'..'
        fx3 = os.path.dirname(PySourceInfo_check.__file__)+os.sep+'..'+os.sep+'..'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePythonPath,2)

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx2 =os.path.abspath(fx2)
        fx3 =os.path.abspath(fx3)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx2 = os.path.normpath(fx2)
        fx3 = os.path.normpath(fx3)
        fx = os.path.normpath(fx)

        assert fx == fx0 or fx == fx1 or fx == fx2 or fx == fx3 
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
"""The package 'pysourceinfo' provides a basic wrapper for Python RTTI on sourcefiles.
It is based on 'inspect'.

"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.8'
__uuid__='efed42d3-f801-4fbb-abfd-bd598d683a82'

__docformat__ = "restructuredtext en"

__package__ = 'pysourceinfo'
__all__=[
    "PySourceInfo",
]




from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase001(self):
        import sys
        _s=sys.path[:]

        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1
       
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        fx0 = "PySourceInfo_check"
        fx1 = "UseCases"
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerSysPathPackageName,1)
        
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx1 or  fx == fx0
        pass

    def testCase002(self):
        import sys
        _s=sys.path[:]
        
        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1

        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx0 = 'getCallerSysPathPackageName'
        fx1 = 'PySourceInfo'
        fx2 = 'UseCases'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerSysPathPackageName,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1 or fx == fx2 

    def testCase003(self):
        import sys
        _s=sys.path[:]

        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1

        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx0 = 'unittest'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerSysPathPackageName,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fx0 = "pysourceinfo"+os.sep+"PySourceInfo.py"
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleFilePathName,0)

        fx0 = os.path.normpath(fx0)
        fx =os.path.abspath(fx)
        fx = os.path.normpath(fx)
        fx = pysourceinfo.PySourceInfo.getPythonPathRel(fx)

        assert fx == fx0

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fx0 = "PySourceInfo_check_tests.py"
        fx1 = "tests/30_libs/040_PySourceInfo/PySourceInfo_check_tests.py"
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleFilePathName,1)
        
        fx0 = os.path.normpath(fx0)
        fx = os.path.normpath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx = os.path.abspath(fx)
        fx = os.path.normpath(fx)

        fx = pysourceinfo.PySourceInfo.getPythonPathRel(fx)

        assert fx == fx0 or fx == fx1

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = "getPythonPathRel/CallCase.py"
        fx1 = "tests/30_libs/040_PySourceInfo/getPythonPathRel/CallCase.py"
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleFilePathName,2)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx = os.path.abspath(fx)
        fx = os.path.normpath(fx)

        fx = pysourceinfo.PySourceInfo.getPythonPathRel(fx)

        assert fx == fx0 or fx == fx1

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            fpn = "unittest.py"
        elif version == '2.7': # pragma: no cover
            fpn = "unittest/case.py"
        else:
            assert False

        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleFilePathName,3)
        fx = pysourceinfo.PySourceInfo.getPythonPathRel(fx)
        fx = os.path.normpath(fx)
        fpn = os.path.normpath(fpn)
        assert fx == fpn
        
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNamespaceGlobal,0)
        fx = fx['__name__']
        
        assert fx == 'pysourceinfo.PySourceInfo'
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

    def testCase001(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNamespaceGlobal,1)
        fx = fx['__name__']

        assert fx == 'PySourceInfo_check'
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

    def testCase002(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx0 = 'UseCases.PySourceInfo.getCallerNamespaceGlobal.CallCase'
        fx1 = 'PySourceInfo.getCallerNamespaceGlobal.CallCase'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNamespaceGlobal,2)
        fx = fx['__name__']

        assert fx == fx0 or fx == fx1
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

    def testCase003(self):
        import sys
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNamespaceGlobal,3)
        fx = fx['__name__']
        
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert fx == 'unittest'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case'
        else:
            assert False
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)
        
if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

from pysourceinfo.PySourceInfo import getStackSposForFunc,getStackFuncList


#
#######################
#
class CallUnits(unittest.TestCase):

    def callFunc(self,cfunc,param):
        return cfunc(param)

    def wrapStackDepth(self,deepness,cfunc,param):
        if deepness > 0:
            _r = self.wrapStackDepth(deepness-1, cfunc, param)
        else:
            return self.callFunc(cfunc,param)
        return _r

    def testCase000(self):
        """verify function - class method - reference on stack
        
        do it here indirect  due to type difference of function and method 
        """
        c = self.wrapStackDepth(4, getStackFuncList,False)
        
        mname = self.testCase000.__name__

        import inspect
        c7fi = inspect.getframeinfo(c[7])

        fname = c7fi[2] 

        a0 = id(c[7]) #@UnusedVariable
        a1 = id(self.testCase000) #@UnusedVariable
        
        ci = self.wrapStackDepth(4, getStackSposForFunc,c[7])

        assert fname == mname
        assert ci == 7
        pass

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase002(self):
        import sys
        _s = sys.path[:]
        
        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1
            
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport

        # Adapts to behaviour of 'inspect'
        fx0 = os.path.dirname(__file__)+os.sep+".."  # this should be the actual and only and one here
        fx1 = os.path.dirname(__file__)+os.sep+".."+os.sep+".."+os.sep+".."
        fx2 = os.path.dirname(__file__)+os.sep+".."+os.sep+".."+os.sep+".."+".."+os.sep+".."
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,2)

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx2 =os.path.abspath(fx2)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx = os.path.normpath(fx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1 or fx == fx2

    def testCase003(self):
        import sys
        _s = sys.path[:]
        
        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1
            
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePathName,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'unittest.py'
        elif version == '2.7': # pragma: no cover
            assert os.path.basename(fx) == 'unittest'
        else:
            assert False

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

from pysourceinfo.PySourceInfo import getStackFuncList, getCallerFunc,getStackLen


#
#######################
#
class CallUnits(unittest.TestCase):

    def callFunc(self,cfunc,param):
        """Function dummy, traces current stack by two different calls, normalizes the calls. 
        """
        cx = cfunc(param)
        cxRef = []
        if not param:
            for i in range(getStackLen()):
                cxRef.append(getCallerFunc(i))
        
            #adapt to different call context
            cx.pop(0)
            cxRef.pop(0)

        else:
            for i in range(getStackLen()):
                cxRef.append(getCallerFunc(i))

            #adapt to different call context
            cx.pop()
            cxRef.pop(0)
            cxRef = [x for x in reversed(cxRef)]
        ret = (cx,cxRef,)
        return ret

    def wrapStackDepth(self,deepness,cfunc,param):
        """Simulates depth of callstack.
        """
        if deepness > 0:
            _r = self.wrapStackDepth(deepness-1, cfunc, param)
        else:
            return self.callFunc(cfunc,param)
        return _r

    def testCase000(self):
        """simple upper call stack
        """
        c = self.wrapStackDepth(4, getStackFuncList,False)
        c0ID = map(id,c[0]) #@UnusedVariable
        c1ID = map(id,c[1]) #@UnusedVariable
        assert c[0] == c[1]
        pass

    def testCase001(self):
        """reversed simple upper call stack
        """
        c = self.wrapStackDepth(4, getStackFuncList,True)
        c0ID = map(id,c[0]) #@UnusedVariable
        c1ID = map(id,c[1]) #@UnusedVariable
        self.assertEqual(c[0], c[1])
        pass

    def testCase002(self):
        """both previous for eventual debugging
        """
        c = self.wrapStackDepth(4, getStackFuncList,False)
        c0ID = map(id,c[0]) #@UnusedVariable
        c1ID = map(id,c[1]) #@UnusedVariable

        d = self.wrapStackDepth(4, getStackFuncList,True)
        d0ID = map(id,d[0]) #@UnusedVariable
        d1ID = map(id,d[1]) #@UnusedVariable

        self.assertEqual(c[0], c[1])
        self.assertEqual(d[0], d[1])
        pass
if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerLinenumber,0)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx > 120 and fx < 200

    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerLinenumber,1)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        self.assertEqual(fx,4)

    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerLinenumber,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        self.assertEqual(fx,47)

    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fxn = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerName,3)
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerLinenumber,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fxn == 'run'

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert fx > 250 and fx < 300 # depends on platform, may require additional, anyhow keep it as a ref
        elif version == '2.7': # pragma: no cover
            assert fx > 300 and fx < 400 # depends on platform, may require additional, anyhow keep it as a ref
        else:
            assert False

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = os.path.abspath(os.path.normpath(os.path.dirname(pysourceinfo.__file__)+os.sep+".."))
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePythonPath,0)
        fx = os.path.normpath(fx)
        assert fx == fpn
        self.assertNotEqual(_sx, repr(sys.path))
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.normpath(os.path.dirname(__file__)+os.sep+'..'))
        sys.path.insert(0,os.path.normpath(os.path.dirname(__file__)))
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn0 = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+os.sep+'..'))
        fpn = os.path.abspath(os.path.normpath(os.path.dirname(PySourceInfo_check_tests.__file__)))

        self.assertEqual(fpn0, fpn)
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePythonPath,1)
        assert fx is not None

        fx = os.path.normpath(fx)
        
        fx1 = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(PySourceInfo_check_tests.__file__)
        assert fx1 is not None

        fx1 = os.path.normpath(fx1)

        # REMARK: currently due to behaviour of PyUnit in conjunction with os.path.curdir
        assert fx == fpn or fx1 == fpn 

        assert _sx != repr(sys.path)
        sys.path.pop(0)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

    def testCase002(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+".."+os.sep+".."+os.sep+".."
        fx1 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+".."+os.sep+".."
        fx2 = os.path.dirname(pysourceinfo.__file__)+os.sep+".."
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePythonPath,2)

        fx0 = os.path.abspath(fx0)
        fx1 = os.path.abspath(fx1)
        fx2 = os.path.abspath(fx2)
        fx = os.path.abspath(fx)
        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx2 = os.path.normpath(fx2)
        fx = os.path.normpath(fx)
        
        assert fx == fx0 or fx == fx1
        
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            fpn = os.path.normpath(os.path.dirname(unittest.__file__))
        elif version == '2.7': # pragma: no cover
            fpn = os.path.normpath(os.path.dirname(unittest.__file__)+os.sep+"..")
        else:
            assert False
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackagePythonPath,3)

        self.assertEqual(os.path.normpath(fx), fpn)
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase002(self):
        import sys
        _s = sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx0 = 'UseCases.PySourceInfo.getCallerNameOID.CallCase.CallUnits.testCase002'
        fx1 = 'PySourceInfo.getCallerNameOID.CallCase.CallUnits.testCase002'
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,2)

        assert fx == fx0 or fx == fx1
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s = sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.abspath(os.path.dirname(__file__)+os.sep+'..'))
        import PySourceInfo_check #@UnresolvedImport
        
        fx = PySourceInfo_check.check_callback(pysourceinfo.PySourceInfo.getCallerNameOID,3)
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert fx == 'unittest.CallUnits.run'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case.CallUnits.run'
        else:
            assert False
        
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        import inspect
        
        fx0 = os.path.dirname(pysourceinfo.__file__)+os.sep+'..'
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModulePythonPath,0)

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx = os.path.normpath(fx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert os.path.normpath(fx) == os.path.normpath(fx0)

    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        #because I rely on inspect, just adapt to it's behaviour        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModulePythonPath,1)
        fx = os.path.normpath(fx)
        fxn = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,1)
        if fxn == 'PySourceInfo_check_tests':
            fpn = os.path.dirname(PySourceInfo_check_tests.__file__)
            fpn = os.path.abspath(os.path.normpath(fpn))
        else:
            fpn = os.path.splitext(os.path.normpath(PySourceInfo_check_tests.__file__))[0]
            import re
            fpn = re.sub(ur"[/\\]*"+fxn+ur"[/\\]*$","",fpn)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fpn

    def testCase002(self):
        import sys
        _s=sys.path[:]

        #Clear from misguided previous tests
        i=len(_s)-1
        for ix in reversed(_s):
            if ix.find('UseCases') != -1:
                sys.path.pop(i)
            i-=1

        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = os.path.dirname(__file__)
        fx1 = os.path.dirname(PySourceInfo_check_tests.__file__)
        fx2 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+'..'
        fx3 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+'..'+os.sep+'..'
        fx4 = os.path.dirname(PySourceInfo_check_tests.__file__)+os.sep+'..'+os.sep+'..'+os.sep+'..'
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModulePythonPath,2)
#        fx += os.sep + "tests" + os.sep + "30_libs" + os.sep + "040_PySourceInfo" + os.sep + "getCallerModulePythonPath"

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx2 =os.path.abspath(fx2)
        fx3 =os.path.abspath(fx3)
        fx4 =os.path.abspath(fx4)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx2 = os.path.normpath(fx2)
        fx3 = os.path.normpath(fx3)
        fx4 = os.path.normpath(fx4)
        fx = os.path.normpath(fx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1 or fx == fx2 or fx == fx3 or fx == fx4

    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            b = os.path.basename(unittest.__file__)[:-4]
            a = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,3)
        elif version == '2.7': # pragma: no cover
            fpn = os.path.dirname(unittest.__file__)
            fpn = os.path.basename(fpn)
            fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModulePythonPath,3)
            a = os.path.normpath(fx+os.sep+fpn)
            b = os.path.normpath(os.path.dirname(unittest.__file__))
        else:
            assert False



        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert a == b 

if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fpn = pysourceinfo.PySourceInfo.getModuleSourceFilePathName(pysourceinfo)
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,0)

        assert os.path.normpath(fx) == fpn
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase001(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        fx0 = os.path.abspath(os.path.normpath(PySourceInfo_check_tests.__file__))
        if fx0[-4:-1] == '.py':
            fx0 = fx0[:-1]

        fx1 = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+os.sep+'..'+os.sep+'..'+os.sep+'..'+os.sep+'__init__.py'))
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,1)
        fx = os.path.normpath(fx)
        
        assert fx == fx0 or fx == fx1
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase002(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = os.path.dirname(__file__)+os.sep+'..'+os.sep+'__init__.py'
        fx1 = os.path.dirname(__file__)+os.sep+'..'+os.sep+'..'+os.sep+'__init__.py'
        fx2 = os.path.dirname(__file__)+os.sep+'..'+os.sep+'..'+os.sep+'..'+os.sep+'__init__.py'
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,2)

        # for relative calls
        fx0 =os.path.abspath(fx0)
        fx1 =os.path.abspath(fx1)
        fx2 =os.path.abspath(fx2)
        fx =os.path.abspath(fx)

        fx0 = os.path.normpath(fx0)
        fx1 = os.path.normpath(fx1)
        fx2 = os.path.normpath(fx2)
        fx = os.path.normpath(fx)
        
        assert fx == fx0 or fx == fx1 or fx == fx2
        
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


    def testCase003(self):
        import sys
        _s=sys.path[:]
        _sx = repr(sys.path)
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        import re
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerPackageFilePathName,3)
        fx= os.path.normpath(fx)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            fx = re.sub(ur".*([/\\]unittest.py)",r'\1',fx)
            assert fx == os.sep+"unittest.py"
        elif version == '2.7': # pragma: no cover
            fx = re.sub(ur".*([/\\]unittest[/\\]__init__.py)",r'\1',fx)
            assert fx == os.sep+"unittest"+os.sep+"__init__.py"
        else:
            assert False
        
        
        assert _sx != repr(sys.path)
        sys.path.pop(0)
        assert _sx == repr(sys.path)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os

import pysourceinfo.PySourceInfo


#
#######################
#
class CallUnits(unittest.TestCase):
    def testCase000(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport

        import inspect
        _is = inspect.getsourcefile(PySourceInfo_check_tests)
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,0)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == 'pysourceinfo.PySourceInfo'

    def testCase001(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,1)
        fx0 = "PySourceInfo_check_tests"
        fx1 = "tests.30_libs.040_PySourceInfo.PySourceInfo_check_tests"

        # due to PyUnit path resolution dependent on curdir

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1

    def testCase002(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx0 = 'tests.30_libs.040_PySourceInfo.getCallerModuleName.CallCase'
        fx1 = '30_libs.040_PySourceInfo.getCallerModuleName.CallCase'
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,2)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert fx == fx0 or fx == fx1

    def testCase003(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,3)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'unittest'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case'
        else:
            assert False


    def testCase004(self):
        import sys
        _s=sys.path[:]
        sys.path.insert(0,os.path.dirname(__file__)+os.sep+'..')
        import PySourceInfo_check_tests #@UnresolvedImport
        
        fx = PySourceInfo_check_tests.check_callback(pysourceinfo.PySourceInfo.getCallerModuleName,4)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        version = '{0}.{1}'.format(*sys.version_info[:2])
        if version == '2.6': # pragma: no cover
            assert os.path.basename(fx) == 'unittest'
        elif version == '2.7': # pragma: no cover
            assert fx == 'unittest.case'
        else:
            assert False


if __name__ == '__main__':
    unittest.main()
